[![Build Status](https://travis-ci.org/applitools/eyes.selenium.python.svg?branch=master)](https://travis-ci.org/applitools/eyes.selenium.python)

eyes.selenium
=============

Applitools Eyes SDK For Selenium Python WebDriver

## Installation

Install the eyes-selenium SDK.
    
    pip install eyes-selenium
    
## Usage

Please check the applitools website for usage instructions:

- Selenium Python example: https://applitools.com/resources/tutorial/selenium/python#step-2

- Python Appium native example: https://applitools.com/resources/tutorial/appium/native_python#step-2

- Python Appium web example: https://applitools.com/resources/tutorial/appium/python#step-2
